<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>CadenceGraph</name>
    <message>
        <location filename="../src/cadencegraph.cpp" line="10"/>
        <source>1/min</source>
        <translation>1/min</translation>
    </message>
    <message>
        <location filename="../src/cadencegraph.cpp" line="11"/>
        <location filename="../src/cadencegraph.h" line="13"/>
        <source>Cadence</source>
        <translation>Kadence</translation>
    </message>
    <message>
        <location filename="../src/cadencegraph.cpp" line="19"/>
        <source>Average</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/cadencegraph.cpp" line="21"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>ElevationGraph</name>
    <message>
        <location filename="../src/elevationgraph.cpp" line="48"/>
        <location filename="../src/elevationgraph.h" line="13"/>
        <source>Elevation</source>
        <translation>Výška</translation>
    </message>
    <message>
        <location filename="../src/elevationgraph.cpp" line="141"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/elevationgraph.cpp" line="58"/>
        <source>Ascent</source>
        <translation>Stoupání</translation>
    </message>
    <message>
        <location filename="../src/elevationgraph.cpp" line="60"/>
        <source>Descent</source>
        <translation>Klesání</translation>
    </message>
    <message>
        <location filename="../src/elevationgraph.cpp" line="64"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/elevationgraph.cpp" line="144"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/elevationgraph.cpp" line="62"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>ExportDialog</name>
    <message>
        <location filename="../src/exportdialog.cpp" line="120"/>
        <source>Export to PDF</source>
        <translation>Exportovat do PDF</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="25"/>
        <source>PDF files (*.pdf);;All files (*)</source>
        <translation>Soubory PDF (*.pdf);;Všechny soubory (*)</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="38"/>
        <source>Portrait</source>
        <translation>Na výšku</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="39"/>
        <source>Landscape</source>
        <translation>Na šířku</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="83"/>
        <source>Page size:</source>
        <translation>Velikost stránky:</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="84"/>
        <source>Orientation:</source>
        <translation>Orientace:</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="80"/>
        <source>Page Setup</source>
        <translation>Nastavení stránky</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="52"/>
        <source>in</source>
        <translation>in</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="52"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="85"/>
        <source>Margins:</source>
        <translation>Okraje:</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="91"/>
        <source>File:</source>
        <translation>Soubor:</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="98"/>
        <source>Output file</source>
        <translation>Výstupní soubor</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="105"/>
        <source>Export</source>
        <translation>Exportovat</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="127"/>
        <location filename="../src/exportdialog.cpp" line="137"/>
        <location filename="../src/exportdialog.cpp" line="142"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="127"/>
        <source>No output file selected.</source>
        <translation>Nebyl zvolen žádný výstupní soubor.</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="137"/>
        <source>%1 is a directory.</source>
        <translation>%1 je adresář.</translation>
    </message>
    <message>
        <location filename="../src/exportdialog.cpp" line="142"/>
        <source>%1 is not writable.</source>
        <translation>%1 nelze zapsat.</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../src/fileselectwidget.cpp" line="38"/>
        <source>Select file</source>
        <translation>Vybrat soubor</translation>
    </message>
</context>
<context>
    <name>Format</name>
    <message>
        <location filename="../src/format.cpp" line="22"/>
        <location filename="../src/format.cpp" line="43"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/format.cpp" line="25"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/format.cpp" line="29"/>
        <location filename="../src/format.cpp" line="40"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/format.cpp" line="32"/>
        <source>km</source>
        <translation>km</translation>
    </message>
</context>
<context>
    <name>GUI</name>
    <message>
        <location filename="../src/gui.cpp" line="578"/>
        <source>GPXSee is distributed under the terms of the GNU General Public License version 3. For more info about GPXSee visit the project homepage at </source>
        <translation>Program GPXSee je distribuován pod podmínkami licence GNU General Public License verze 3. Pro více informací navštivte stránky programu na adrese </translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="650"/>
        <source>Open file</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="740"/>
        <source>Open POI file</source>
        <translation>Otevřít POI soubor</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="237"/>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="221"/>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="229"/>
        <location filename="../src/gui.cpp" line="594"/>
        <location filename="../src/gui.cpp" line="595"/>
        <source>Keyboard controls</source>
        <translation>Ovládací klávesy</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="253"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="259"/>
        <source>Reload</source>
        <translation>Znovu načíst</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="508"/>
        <source>Show</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="426"/>
        <location filename="../src/gui.cpp" line="502"/>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="105"/>
        <source>FIT files (*.fit)</source>
        <translation>Soubory FIT (*.fit)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="106"/>
        <source>IGC files (*.igc)</source>
        <translation>Soubory IGC (*.igc)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="107"/>
        <source>NMEA files (*.nmea)</source>
        <translation>Soubory NMEA (*.nmea)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="227"/>
        <location filename="../src/gui.cpp" line="617"/>
        <location filename="../src/gui.cpp" line="618"/>
        <source>Data sources</source>
        <translation>Zdroje dat</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="267"/>
        <source>Load POI file</source>
        <translation>Nahrát POI soubor</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="270"/>
        <source>Close POI files</source>
        <translation>Zavřit POI soubory</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="272"/>
        <source>Overlap POIs</source>
        <translation>Překrývat POI</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="276"/>
        <source>Show POI labels</source>
        <translation>Zobrazit názvy POI</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="281"/>
        <source>Show POIs</source>
        <translation>Zobrazit POI</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="290"/>
        <source>Show map</source>
        <translation>Zobrazit mapu</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="297"/>
        <source>Clear tile cache</source>
        <translation>Vymazat mezipaměť dlaždic</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="306"/>
        <location filename="../src/gui.cpp" line="310"/>
        <location filename="../src/gui.cpp" line="606"/>
        <source>Next map</source>
        <translation>Následující mapa</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="317"/>
        <source>Show tracks</source>
        <translation>Zobrazit cesty</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="321"/>
        <source>Show routes</source>
        <translation>Zobrazit trasy</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="325"/>
        <source>Show waypoints</source>
        <translation>Zobrazit navigační body</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="329"/>
        <source>Waypoint labels</source>
        <translation>Názvy navigačních bodů</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="340"/>
        <source>Show graphs</source>
        <translation>Zobrazit grafy</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="362"/>
        <source>Show grid</source>
        <translation>Zobrazit mřížku</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="368"/>
        <source>Show toolbars</source>
        <translation>Zobrazovat nástrojové lišty</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="374"/>
        <source>Total time</source>
        <translation>Celkový čas</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="379"/>
        <location filename="../src/gui.cpp" line="893"/>
        <source>Moving time</source>
        <translation>Čistý čas</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="386"/>
        <source>Metric</source>
        <translation>Metrické</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="391"/>
        <source>Imperial</source>
        <translation>Imperiální</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="397"/>
        <source>Fullscreen mode</source>
        <translation>Celoobrazovkový režim</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="403"/>
        <source>Options...</source>
        <translation>Nastavení...</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="408"/>
        <source>Next</source>
        <translation>Následující</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="411"/>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="415"/>
        <source>Last</source>
        <translation>Poslední</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="418"/>
        <source>First</source>
        <translation>První</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="440"/>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="447"/>
        <source>Graph</source>
        <translation>Graf</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="455"/>
        <source>POI</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="456"/>
        <source>POI files</source>
        <translation>POI soubory</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="467"/>
        <source>Data</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="468"/>
        <source>Display</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="476"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="480"/>
        <source>Units</source>
        <translation>Jednotky</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="489"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="607"/>
        <source>Previous map</source>
        <translation>Předchozí mapa</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="620"/>
        <source>Online maps</source>
        <translation>Online mapy</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="621"/>
        <source>Online map URLs are read on program startup from the following file:</source>
        <translation>URL online map jsou načteny při startu programu z následujícího souboru:</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="631"/>
        <source>Ofline maps</source>
        <translation>Offline mapy</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="632"/>
        <source>Offline maps are loaded on program startup from the following directory:</source>
        <translation>Offline mapy jsou načítány při startu aplikace z následujícího adresáře:</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="635"/>
        <source>The expected structure is one map/atlas in a separate subdirectory. Supported map formats are OziMap image-based maps and tiled TrekBuddy maps/atlases (tared and non-tared).</source>
        <translation>Očekávaná struktura je jedna mapa/atlas v samostatném podadresáři. Podporované mapové formáty jsou OziMap mapy a TrekBuddy mapy/atlasy (včetně tar varianty).</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="1091"/>
        <source>No files loaded</source>
        <translation>Nejsou načteny žádné soubory</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="106"/>
        <source>GPX files (*.gpx)</source>
        <translation>Soubory GPX (*.gpx)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="108"/>
        <source>TCX files (*.tcx)</source>
        <translation>Soubory TCX (*.tcx)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="107"/>
        <source>KML files (*.kml)</source>
        <translation>Soubory KML (*.kml)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="105"/>
        <source>CSV files (*.csv)</source>
        <translation>Soubory CSV (*.csv)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="108"/>
        <source>All files (*)</source>
        <translation>Všechny soubory (*)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="879"/>
        <location filename="../src/gui.cpp" line="882"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="871"/>
        <source>Routes</source>
        <translation>Trasy</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/gui.cpp" line="1095"/>
        <source>%n files</source>
        <translation>
            <numerusform>%n soubor</numerusform>
            <numerusform>%n soubory</numerusform>
            <numerusform>%n souborů</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="597"/>
        <source>Next file</source>
        <translation>Následující soubor</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="575"/>
        <source>Version </source>
        <translation>Verze </translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="242"/>
        <source>Print...</source>
        <translation>Tisknout...</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="247"/>
        <source>Export to PDF...</source>
        <translation>Exportovat do PDF...</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="873"/>
        <source>Waypoints</source>
        <translation>Navigační body</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="599"/>
        <source>Previous file</source>
        <translation>Předchozí soubor</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="104"/>
        <source>Supported files (*.csv *.fit *.gpx *.igc *.kml *.nmea *.tcx)</source>
        <translation>Podporované soubory (*.csv *.fit *.gpx *.igc *.kml *.nmea *.tcx)</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="333"/>
        <source>Route waypoints</source>
        <translation>Body tras</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="601"/>
        <source>First file</source>
        <translation>První soubor</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="603"/>
        <source>Last file</source>
        <translation>Poslední soubor</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="604"/>
        <source>Append modifier</source>
        <translation>Modifikátor nahradit/přidat</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="624"/>
        <source>The file format is one map entry per line, consisting of the map name and tiles URL delimited by a TAB character. The tile X and Y coordinates are replaced with $x and $y in the URL and the zoom level is replaced with $z. An example map file could look like:</source>
        <translation>Formát souboru je jeden mapový záznam na řádku, kde mapový záznam sestává ze jména mapy a URL dlaždic navzájem oddělených tabulátorem. Souřadnice dlaždice jsou v URL nahrazeny řetězci $x a $y, úroven přiblížení (zoom) pak řetězcem $z. Příklad:</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="640"/>
        <source>To make GPXSee load a POI file automatically on startup, add the file to the following directory:</source>
        <translation>POI soubory, které se mají automaticky nahrát při startu programu jsou načítány z následujícího adresáře:</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="729"/>
        <source>Error loading data file:</source>
        <translation>Datový soubor nelze načíst:</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="732"/>
        <location filename="../src/gui.cpp" line="757"/>
        <source>Line: %1</source>
        <translation>Řádka: %1</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="754"/>
        <source>Error loading POI file:</source>
        <translation>Soubor POI nelze načíst:</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="865"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="869"/>
        <source>Tracks</source>
        <translation>Cesty</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="232"/>
        <location filename="../src/gui.cpp" line="574"/>
        <source>About GPXSee</source>
        <translation>O aplikaci GPXSee</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="513"/>
        <source>Navigation</source>
        <translation>Navigace</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="639"/>
        <source>POIs</source>
        <translation>POI body</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="348"/>
        <location filename="../src/gui.cpp" line="889"/>
        <source>Distance</source>
        <translation>Vzdálenost</translation>
    </message>
    <message>
        <location filename="../src/gui.cpp" line="355"/>
        <location filename="../src/gui.cpp" line="477"/>
        <location filename="../src/gui.cpp" line="891"/>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
</context>
<context>
    <name>GraphView</name>
    <message>
        <location filename="../src/graphview.cpp" line="108"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/graphview.cpp" line="111"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/graphview.cpp" line="116"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/graphview.cpp" line="119"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/graphview.cpp" line="125"/>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../src/graphview.cpp" line="128"/>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <location filename="../src/graphview.cpp" line="131"/>
        <source>h</source>
        <translation>h</translation>
    </message>
    <message>
        <location filename="../src/graphview.cpp" line="60"/>
        <location filename="../src/graphview.cpp" line="157"/>
        <source>Distance</source>
        <translation>Vzdálenost</translation>
    </message>
    <message>
        <location filename="../src/graphview.cpp" line="159"/>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
</context>
<context>
    <name>HeartRateGraph</name>
    <message>
        <location filename="../src/heartrategraph.cpp" line="11"/>
        <location filename="../src/heartrategraph.h" line="13"/>
        <source>Heart rate</source>
        <translation>Tep</translation>
    </message>
    <message>
        <location filename="../src/heartrategraph.cpp" line="10"/>
        <source>1/min</source>
        <translation>1/min</translation>
    </message>
    <message>
        <location filename="../src/heartrategraph.cpp" line="19"/>
        <source>Average</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/heartrategraph.cpp" line="21"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../src/optionsdialog.cpp" line="34"/>
        <source>Base color:</source>
        <translation>Základní barva:</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="35"/>
        <source>Palette shift:</source>
        <translation>Posun palety:</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="47"/>
        <source>Track width:</source>
        <translation>Šířka cest:</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="48"/>
        <source>Track style:</source>
        <translation>Styl cest:</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="50"/>
        <source>Tracks</source>
        <translation>Cesty</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="60"/>
        <source>Route width:</source>
        <translation>Šířka tras:</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="61"/>
        <source>Route style:</source>
        <translation>Styl tras:</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="63"/>
        <source>Routes</source>
        <translation>Trasy</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="67"/>
        <location filename="../src/optionsdialog.cpp" line="99"/>
        <source>Use anti-aliasing</source>
        <translation>Vyhlazovat hrany</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="97"/>
        <source>Line width:</source>
        <translation>Šířka čar:</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="113"/>
        <source>Colors</source>
        <translation>Barvy</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="114"/>
        <source>Paths</source>
        <translation>Trasy</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="115"/>
        <location filename="../src/optionsdialog.cpp" line="183"/>
        <source>Graphs</source>
        <translation>Grafy</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="127"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="130"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="134"/>
        <source>POI radius:</source>
        <translation>POI radius:</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="140"/>
        <location filename="../src/optionsdialog.cpp" line="224"/>
        <source>POI</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="147"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="149"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="151"/>
        <source>Distance</source>
        <translation>Vzdálenost</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="153"/>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="155"/>
        <source>Moving time</source>
        <translation>Čistý čas</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="157"/>
        <source>Item count (&gt;1)</source>
        <translation>Počet objektů (&gt;1)</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="172"/>
        <source>Separate graph page</source>
        <translation>Samostatná stránka s grafy</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="182"/>
        <source>Header</source>
        <translation>Záhlaví</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="190"/>
        <source>Use OpenGL</source>
        <translation>Používat OpenGL</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="206"/>
        <location filename="../src/optionsdialog.cpp" line="227"/>
        <source>System</source>
        <translation>Systém</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="222"/>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="225"/>
        <source>Print &amp; Export</source>
        <translation>Tisk a export</translation>
    </message>
    <message>
        <location filename="../src/optionsdialog.cpp" line="254"/>
        <source>Options</source>
        <translation>Nastavení</translation>
    </message>
</context>
<context>
    <name>PowerGraph</name>
    <message>
        <location filename="../src/powergraph.cpp" line="10"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/powergraph.cpp" line="11"/>
        <location filename="../src/powergraph.h" line="13"/>
        <source>Power</source>
        <translation>Výkon</translation>
    </message>
    <message>
        <location filename="../src/powergraph.cpp" line="19"/>
        <source>Average</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/powergraph.cpp" line="21"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>RouteItem</name>
    <message>
        <location filename="../src/routeitem.cpp" line="15"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/routeitem.cpp" line="17"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../src/routeitem.cpp" line="18"/>
        <source>Distance</source>
        <translation>Vzdálenost</translation>
    </message>
</context>
<context>
    <name>ScaleItem</name>
    <message>
        <location filename="../src/scaleitem.cpp" line="81"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/scaleitem.cpp" line="82"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/scaleitem.cpp" line="84"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/scaleitem.cpp" line="85"/>
        <source>m</source>
        <translation>m</translation>
    </message>
</context>
<context>
    <name>SpeedGraph</name>
    <message>
        <location filename="../src/speedgraph.cpp" line="13"/>
        <location filename="../src/speedgraph.h" line="14"/>
        <source>Speed</source>
        <translation>Rychlost</translation>
    </message>
    <message>
        <location filename="../src/speedgraph.cpp" line="79"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/speedgraph.cpp" line="21"/>
        <source>Average</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/speedgraph.cpp" line="23"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/speedgraph.cpp" line="82"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
</context>
<context>
    <name>TemperatureGraph</name>
    <message>
        <location filename="../src/temperaturegraph.cpp" line="11"/>
        <location filename="../src/temperaturegraph.h" line="13"/>
        <source>Temperature</source>
        <translation>Teplota</translation>
    </message>
    <message>
        <location filename="../src/temperaturegraph.cpp" line="19"/>
        <source>Average</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/temperaturegraph.cpp" line="21"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/temperaturegraph.cpp" line="23"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/temperaturegraph.cpp" line="81"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/temperaturegraph.cpp" line="85"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>TrackItem</name>
    <message>
        <location filename="../src/trackitem.cpp" line="13"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/trackitem.cpp" line="15"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../src/trackitem.cpp" line="16"/>
        <source>Distance</source>
        <translation>Vzdálenost</translation>
    </message>
    <message>
        <location filename="../src/trackitem.cpp" line="18"/>
        <source>Total time</source>
        <translation>Celkový čas</translation>
    </message>
    <message>
        <location filename="../src/trackitem.cpp" line="20"/>
        <source>Moving time</source>
        <translation>Čistý čas</translation>
    </message>
    <message>
        <location filename="../src/trackitem.cpp" line="22"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
</context>
<context>
    <name>WaypointItem</name>
    <message>
        <location filename="../src/waypointitem.cpp" line="18"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/waypointitem.cpp" line="19"/>
        <source>Coordinates</source>
        <translation>Souřadnice</translation>
    </message>
    <message>
        <location filename="../src/waypointitem.cpp" line="22"/>
        <source>Elevation</source>
        <translation>Výška</translation>
    </message>
    <message>
        <location filename="../src/waypointitem.cpp" line="25"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../src/waypointitem.cpp" line="28"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
</context>
</TS>
